package com.gprinter.zb;

import java.io.FilterOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/* loaded from: com_gprinter_zb.jar:com/gprinter/zb/ZPLUtilities.class */
public class ZPLUtilities {
    public static final int ZPL_INTERNAL_FORMAT_PREFIX_CHAR = 30;
    public static final int ZPL_INTERNAL_COMMAND_PREFIX_CHAR = 16;
    public static final int ZPL_INTERNAL_DELIMITER_CHAR = 31;
    public static final String ZPL_INTERNAL_FORMAT_PREFIX = new String(new byte[]{30});
    public static final String ZPL_INTERNAL_COMMAND_PREFIX = new String(new byte[]{16});
    public static final String ZPL_INTERNAL_DELIMITER = new String(new byte[]{31});
    public static final String PRINTER_INFO = "\u0010HI";
    public static final String PRINTER_STATUS = "\u0010HS";
    public static final String PRINTER_CONFIG_LABEL = "\u0010WC";
    public static final String PRINTER_DIRECTORY_LABEL = "\u001eXA\u001eWD*:*.*\u001eXZ";
    public static final String PRINTER_NETWORK_CONFIG_LABEL = "\u0010WL";
    public static final String PRINTER_CALIBRATE = "\u0010JC";
    public static final String PRINTER_RESET = "\u0010JR";
    public static final String PRINTER_RESET_NETWORK = "\u0010WR";
    public static final String PRINTER_RESTORE_DEFAULTS = "\u001eXA\u001eJUF\u001eXZ";
    public static final String PRINTER_GET_SUPER_HOST_STATUS = "\u001eXA\u001eHZA\u001eXZ";
    public static final String PRINTER_GET_STORAGE_INFO_COMMAND = "\u001eXA\u001eHW*:XXXX.QQQ\u001eXZ";
    public static final String FILE_DRIVE_INFO_SETTING_NAME = "file.drive_info";
    public static final String FILE_DRIVE_LISTING_SETTING_NAME = "file.drive_listing";

    /* loaded from: com_gprinter_zb.jar:com/gprinter/zb/ZPLUtilities$FileObjectDetails.class */
    private static class FileObjectDetails {
        public String access;
        public String storage;
        public long size;
        public long free;
    }

    public static String decorateWithCommandPrefix(String var0) {
        if (var0 == null) {
            return null;
        }
        return var0.indexOf("~") != -1 ? var0.replace('~', (char) 16) : ZPL_INTERNAL_COMMAND_PREFIX + var0;
    }

    public static String decorateWithFormatPrefix(String var0) {
        if (var0 == null) {
            return null;
        }
        return var0.indexOf("^") != -1 ? var0.replace('^', (char) 30) : ZPL_INTERNAL_FORMAT_PREFIX + var0;
    }

    public static String replaceAllWithInternalDelimeter(String var0) {
        if (var0 == null) {
            return null;
        }
        return var0.replaceAll(",", ZPL_INTERNAL_DELIMITER);
    }

    public static String replaceAllWithInternalCharacters(String var0) {
        if (var0 == null) {
            return null;
        }
        return replaceAllWithInternalDelimeter(var0).replace("^", ZPL_INTERNAL_FORMAT_PREFIX).replace("~", ZPL_INTERNAL_COMMAND_PREFIX);
    }

    public static String replaceInternalCharactersWithReadableCharacters(String var0) {
        return var0.replaceAll(ZPL_INTERNAL_COMMAND_PREFIX, "~").replaceAll(ZPL_INTERNAL_FORMAT_PREFIX, "^").replaceAll(ZPL_INTERNAL_DELIMITER, ",");
    }

    public static byte[] replaceInternalCharactersWithReadableCharacters(byte[] var0) {
        for (int var1 = 0; var1 < var0.length; var1++) {
            if (var0[var1] == 16) {
                var0[var1] = 126;
            } else if (var0[var1] == 31) {
                var0[var1] = 44;
            } else if (var0[var1] == 30) {
                var0[var1] = 94;
            }
        }
        return var0;
    }

    public static int getDpmm(String var0) {
        String[] var1 = var0.split(",");
        if (var1.length >= 3) {
            try {
                return Integer.parseInt(var1[2]);
            } catch (NumberFormatException e) {
                return -1;
            }
        }
        return -1;
    }

    public static String[] filterFileList(String[] var0, String var1) {
        if (var1 == null || var1.equals("")) {
            var1 = "*:*.*";
        }
        Pattern var2 = Pattern.compile("(([A-Za-z\\*]{1}):)?([A-Za-z0-9\\-_\\*]+)\\.([A-Za-z0-9\\-_\\*]+)");
        Matcher var3 = var2.matcher(var1);
        if (!var3.matches()) {
            return new String[0];
        }
        Pattern var4 = Pattern.compile(createFileNameRegex(var3));
        ArrayList var5 = new ArrayList();
        for (String var9 : var0) {
            Matcher var10 = var4.matcher(var9);
            if (var10.matches()) {
                var5.add(var9);
            }
        }
        return (String[]) var5.toArray(new String[0]);
    }

    private static String createFileNameRegex(Matcher var0) {
        String var3 = var0.group(1);
        String var32 = var3 == null ? "([A-Za-z]{1}:)?" : var3.replaceAll("\\*:", "([A-Za-z]{1}:)?");
        String var4 = var0.group(3).replaceAll("\\*", "[A-Za-z0-9\\-_]*");
        String var5 = var0.group(4).replaceAll("\\*", "[A-Za-z0-9\\-_]*");
        return var32 + var4 + "\\." + var5;
    }

    public static String getDYPrefix(char var0, String var1, char var2, String var3, int var4, String var5) {
        StringBuilder var6 = new StringBuilder();
        var6.append(ZPL_INTERNAL_COMMAND_PREFIX).append("DY").append(var0).append(':').append(var1).append(ZPL_INTERNAL_DELIMITER).append(var2);
        var6.append(ZPL_INTERNAL_DELIMITER).append(var3).append(ZPL_INTERNAL_DELIMITER).append(String.valueOf(var4)).append(ZPL_INTERNAL_DELIMITER).append(var5).append(ZPL_INTERNAL_DELIMITER);
        return var6.toString();
    }

    public static boolean isValidZplFirmware(String var0) {
        if (var0 == null) {
            return false;
        }
        Pattern var1 = Pattern.compile("[Vv][\\w-]+\\.[\\w-]+\\.[\\w-]+");
        Matcher var2 = var1.matcher(var0);
        return var2.matches();
    }

    /* loaded from: com_gprinter_zb.jar:com/gprinter/zb/ZPLUtilities$InternalCharacterFilteringOutputStream.class */
    class InternalCharacterFilteringOutputStream extends FilterOutputStream {
        public InternalCharacterFilteringOutputStream(OutputStream var2) {
            super(var2);
        }

        @Override // java.io.FilterOutputStream, java.io.OutputStream
        public void write(int var1) throws IOException {
            if (var1 == 16) {
                var1 = 126;
            } else if (var1 == 31) {
                var1 = 44;
            } else if (var1 == 30) {
                var1 = 94;
            }
            super.write(var1);
        }
    }
}
